==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOEQUIPMENTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type", propOrder = {
    "functionid",
    "woequipmenttype"
})
public class FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type {

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "WOEQUIPMENTTYPE", required = true)
    protected TYPE_Type woequipmenttype;

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété woequipmenttype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWOEQUIPMENTTYPE() {
        return woequipmenttype;
    }

    /**
     * Définit la valeur de la propriété woequipmenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWOEQUIPMENTTYPE(TYPE_Type value) {
        this.woequipmenttype = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOEQUIPMENTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type", propOrder = {
    "functionid",
    "woequipmenttype"
})
public class FIELDFILTERSETUPWOEQUIPMENTTYPEID_Type {

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "WOEQUIPMENTTYPE", required = true)
    protected TYPE_Type woequipmenttype;

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the woequipmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWOEQUIPMENTTYPE() {
        return woequipmenttype;
    }

    /**
     * Sets the value of the woequipmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWOEQUIPMENTTYPE(TYPE_Type value) {
        this.woequipmenttype = value;
    }

}
